#include "stdafx.h"
#include "Antidote APIOle VCpp MFC.h"
#include "Antidote APIOle VCpp MFCDoc.h"

#include "ChildFrm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

IMPLEMENT_DYNCREATE(CChildFrame, CMDIChildWnd)

BEGIN_MESSAGE_MAP(CChildFrame, CMDIChildWnd)
END_MESSAGE_MAP()

CChildFrame::CChildFrame()
{
}

CChildFrame::~CChildFrame()
{
}

BOOL CChildFrame::PreCreateWindow(CREATESTRUCT& cs)
{
	if( !CMDIChildWnd::PreCreateWindow(cs) )
		return FALSE;

	return TRUE;
}

#ifdef _DEBUG
void CChildFrame::AssertValid() const
{
	CMDIChildWnd::AssertValid();
}

void CChildFrame::Dump(CDumpContext& dc) const
{
	CMDIChildWnd::Dump(dc);
}

#endif //_DEBUG


// ----------------------------------------------------------------------------
// DonnePosSel : Retourne le dbut et la fin de la slection dans la zone de texte 'idZoneDeTexte' 
//
// DonnePosSel: Returns the beginning and end of the selection in the text box 'idZoneDeTexte'
// ----------------------------------------------------------------------------
void CChildFrame::DonnePosSel(long idZoneDeTexte, long& debut, long& fin)
{
  // Dans cet exemple, il y a une seule zone de texte par document.
  // Pour les applications dont les documents contiennent plusieurs zones de texte, vous devez utiliser le paramtre 'idZoneDeTexte' pour savoir  quelle zone Antidote s'adresse.
	//
	// In this example, each document contains only one text box.
	// For documents containing multiple text boxes, use the parameter 'idZoneDeTexte' to find the one that Antidote addresses.
	monDoc = (CRichEditDoc*)GetActiveDocument();
	CRichEditCtrl& maZoneDeTexte = monDoc->GetView()->GetRichEditCtrl();
	if (maZoneDeTexte)
	  maZoneDeTexte.GetSel(debut, fin);
}

// ----------------------------------------------------------------------------
// DonneIdDocument
// ----------------------------------------------------------------------------
long CChildFrame::DonneIdDocument()
{
  // Dans cet exemple, le HWND du "ChildFrame" est utilis comme id du document.
	//
	// In this example, the HWND of the "ChildFrame" is used as the document ID.
	return long(GetSafeHwnd());
}

// ----------------------------------------------------------------------------
// DonneIdZoneDeTexte
// ----------------------------------------------------------------------------
long CChildFrame::DonneIdZoneDeTexte(long indiceZoneDeTexte)
{
  // Dans cet exemple, il y a une seule zone de texte par document.
	// La mthode retourne le handle de l'diteur (RichEditCtrl) comme id de la zone de texte.
	//
	// In this example, each document contains only one text box.
	// The editor's HWND (RichEditCtrl) is used as the text box ID.


  // Pour les applications dont les documents contiennent plusieurs zones de texte, Antidote va appeler successivement cette mthode pour obtenir l'id de chacune des zones de texte.
	//
	// For documents containing multiple text boxes, Antidote calls this method to obtain each text box ID.
	monDoc = (CRichEditDoc*)GetActiveDocument();
	CRichEditCtrl& maZoneDeTexte = monDoc->GetView()->GetRichEditCtrl();
 	return maZoneDeTexte ? long(maZoneDeTexte.GetSafeHwnd()) : 0;
}

// ----------------------------------------------------------------------------
// DonneIdZoneDeTexteCourante
// ----------------------------------------------------------------------------
long CChildFrame::DonneIdZoneDeTexteCourante()
{
  // Dans cet exemple, il y a une seule zone de texte par document. La mthode retourne l'identificateur de la premire zone de texte.
  // Pour les applications dont les documents contiennent plusieurs zones de texte, vous devez retourner l'id de la zone de texte courante (celle qui contient le curseur d'insertion).
	//
	// In this example, each document contains only one text box. This method returns the identifier of the first (and only) text box.
	// For documents containing multiple text boxes, return the ID of the current text box (where the text cursor is currently placed).
	return DonneIdZoneDeTexte(1);
}

// ----------------------------------------------------------------------------
// DonneIntervalle
// ----------------------------------------------------------------------------
void CChildFrame::DonneIntervalle(long idZoneDeTexte, long debut, long fin, CString &strIntervalle)
{
  // Dans cet exemple, il y a une seule zone de texte par document.
  // Pour les applications dont les documents contiennent plusieurs zones de texte, vous devez utiliser le paramtre 'idZoneDeTexte' pour savoir  quelle zone Antidote s'adresse.
	//
	// In this example, each document contains only one text box.
	// For documents containing multiple text boxes, use the parameter 'idZoneDeTexte' to find the one that Antidote addresses.

	strIntervalle = "";
	monDoc = (CRichEditDoc*)GetActiveDocument();
	CRichEditCtrl& maZoneDeTexte = monDoc->GetView()->GetRichEditCtrl();
	if (maZoneDeTexte)
  {
		TCHAR* leTexte = new TCHAR[fin - debut + 1];
		TEXTRANGE textRange;
		textRange.lpstrText = leTexte;
		textRange.chrg.cpMin = debut;
		textRange.chrg.cpMax = fin;

	 	LRESULT lResult = maZoneDeTexte.SendMessage(EM_GETTEXTRANGE, 0, (LPARAM)&textRange);
		
			if (lResult > 0)
			strIntervalle = leTexte;

		delete [] leTexte;
	}
}

// ----------------------------------------------------------------------------
// DonneLongueurZoneDeTexte
// ----------------------------------------------------------------------------
long CChildFrame::DonneLongueurZoneDeTexte(long idZoneDeTexte)
{
  // Dans cet exemple, il y a une seule zone de texte par document. La mthode retourne donc la longueur du document.
  // Pour les applications dont les documents contiennent plusieurs zones de texte, vous devez retourner la longueur du texte dans la zone de texte spcifi par 'idZoneDeTexte'
	//
	// In this example, each document contains only one text box. This method returns the entire length of the document.
	// For documents containing multiple text boxes, return the number of characters in the text box indicated by 'idZoneDeTexte'.

	monDoc = (CRichEditDoc*)GetActiveDocument();
	CRichEditCtrl& maZoneDeTexte = monDoc->GetView()->GetRichEditCtrl();
	return maZoneDeTexte ? maZoneDeTexte.GetTextLength() : -1;
}

// ----------------------------------------------------------------------------
// DonneNbZonesDeTexte
// ----------------------------------------------------------------------------
long CChildFrame::DonneNbZonesDeTexte()
{
  // Dans cet exemple, il y a une seule zone de texte par document.
  // Pour les applications dont les documents contiennent plusieurs zones de texte, vous devez retourner le nombre de zones de texte contenues dans le document actif.
	//
	// In this example, each document contains only one text box. For documents containing multiple text boxes, return the number of text boxes in the current document.
	return 1;
}

// ----------------------------------------------------------------------------
// DonnePolice
// ----------------------------------------------------------------------------
void CChildFrame::DonnePolice(long idZoneDeTexte, CString &strNomPolice)
{
	// Mthode obsolte prsente pour rtrocompatibilit uniquement. Retourner une chaine vide.
	//
	// Obsolete method present only for reasons of backward compatibility. Returns an empty string.
	strNomPolice = "";
}

// ----------------------------------------------------------------------------
// RemplaceIntervalle
// ----------------------------------------------------------------------------
void CChildFrame::RemplaceIntervalle(long idZoneDeTexte, long leDebut, long laFin, BSTR* laChaine)
{
  // Dans cet exemple, il y a une seule zone de texte par document.
  // Pour les applications dont les documents contiennent plusieurs zones de texte, vous devez utiliser le paramtre 'idZoneDeTexte' pour savoir  quelle zone Antidote s'adresse.
	//
	// In this example, each document contains only one text box.
	// For documents containing multiple text boxes, use the parameter 'idZoneDeTexte' to find the one that Antidote addresses.

	SelectionneIntervalle(idZoneDeTexte, leDebut, laFin);
	monDoc = (CRichEditDoc*)GetActiveDocument();
	CRichEditCtrl& maZoneDeTexte = monDoc->GetView()->GetRichEditCtrl();
	if (maZoneDeTexte)
	{
		CW2T pszT( *laChaine );
		maZoneDeTexte.ReplaceSel(pszT);
	}
}

// ----------------------------------------------------------------------------
// SelectionneIntervalle
// ----------------------------------------------------------------------------
void CChildFrame::SelectionneIntervalle(long idZoneDeTexte, long leDebut, long laFin)
{
  // Dans cet exemple, il y a une seule zone de texte par document.
  // Pour les applications dont les documents contiennent plusieurs zones de texte, vous devez utiliser le paramtre 'idZoneDeTexte' pour savoir  quelle zone Antidote s'adresse.
	//
	// In this example, each document contains only one text box.
	// For documents containing multiple text boxes, use the parameter 'idZoneDeTexte' to find the one that Antidote addresses.

	monDoc = (CRichEditDoc*)GetActiveDocument();
	CRichEditCtrl& maZoneDeTexte = monDoc->GetView()->GetRichEditCtrl();
	if (maZoneDeTexte)
		maZoneDeTexte.SetSel(leDebut, laFin);
}
