﻿using System;
using System.Drawing;
using System.Runtime.InteropServices;
using System.Threading;
using System.Windows.Forms;

namespace Antidote_APIOle_VCSharp_dotNet
{
	// Tous les appels provenant d'Antidote transitent vers cette classe
	// Puisque le serveur COM est sur un fil secondaire et que les éléments graphiques sont sur le fil principal, il faut envoyer l'appel sur le fil principal (voir fonction RouleSurFilPrincipal)
	// 
	// All calls from Antidote go through this class.
	// Since the COM server is on a secondary thread and the GUI elements are on the primary thread, the call must be sent to the primary thread (using RouleSurFilPrincipal).
	[ClassInterface(ClassInterfaceType.None)]
	[ComDefaultInterface(typeof(IServeurClient))] 
	[ComVisible(true)]
	public partial class ServeurClient : IServeurClient
	{
		private static ServeurClient singleton = null;

		private ServeurClient() { }

		public static ServeurClient Instance()
		{
			if (singleton == null)
			{
				singleton = new ServeurClient();
			}
			return singleton;
		}

		public void ActiveApplication() 
		{
			Delegate del = new frmMDIMain.DelegateActiveApplication(frmMDIMain.Instance().ActiveApplication);
			RouleSurFilPrincipal(del);
		}

		public void ActiveDocument(long idDoc)
		{
			Delegate del = new frmMDIMain.DelegateActiveDocument(frmMDIMain.Instance().ActiveDocument);
			object[] obj = new object[1];
			obj[0] = idDoc;
			RouleSurFilPrincipal(del, ref obj);
		}

		public long DonneDebutSelection(long idDoc, long idZone)
		{
			Delegate del = new frmMDIMain.DelegateDonneDebutSelection(frmMDIMain.Instance().DonneDebutSelection);
			object[] obj = new object[2];
			obj[0] = idDoc;
			obj[1] = idZone;
			return (long)RouleSurFilPrincipal(del, ref obj);
		}

		public long DonneFinSelection(long idDoc, long idZone)
		{
			Delegate del = new frmMDIMain.DelegateDonneFinSelection(frmMDIMain.Instance().DonneFinSelection);
			object[] obj = new object[2];
			obj[0] = idDoc;
			obj[1] = idZone;
			return (long)RouleSurFilPrincipal(del, ref obj);
		}

		public long DonneIdDocumentCourant()
		{
			Delegate del = new frmMDIMain.DelegateDonneIdDocumentCourant(frmMDIMain.Instance().DonneIdDocumentCourant);
			return (long)RouleSurFilPrincipal(del);
		}

		public long DonneIdZoneDeTexte(long id, long indice)
		{
			Delegate del = new frmMDIMain.DelegateDonneIdZoneDeTexte(frmMDIMain.Instance().DonneIdZoneDeTexte);
			object[] obj = new object[2];
			obj[0] = id;
			obj[1] = indice;
			return (long)RouleSurFilPrincipal(del, ref obj);
		}

		public long DonneIdZoneDeTexteCourante(long id)
		{
			Delegate del = new frmMDIMain.DelegateDonneIdZoneDeTexteCourante(frmMDIMain.Instance().DonneIdZoneDeTexteCourante);
			object[] obj = new object[1];
			obj[0] = id;
			return (long)RouleSurFilPrincipal(del, ref obj);
		}

		public string DonneIntervalle(long idDoc, long idZone, long leDebut, long laFin)
		{
			Delegate del = new frmMDIMain.DelegateDonneIntervalle(frmMDIMain.Instance().DonneIntervalle);
			object[] obj = new object[4];
			obj[0] = idDoc;
			obj[1] = idZone;
			obj[2] = (int)leDebut;
			obj[3] = (int)laFin;
			return (string)RouleSurFilPrincipal(del, ref obj);
		}

		public long DonneLongueurZoneDeTexte(long idDoc, long idZone)
		{
			Delegate del = new frmMDIMain.DelegateDonneLongueurZoneDeTexte(frmMDIMain.Instance().DonneLongueurZoneDeTexte);
			object[] obj = new object[2];
			obj[0] = idDoc;
			obj[1] = idZone;
			return (long)RouleSurFilPrincipal(del, ref obj);
		}

		public long DonneNbZonesDeTexte(long id)
		{
			Delegate del = new frmMDIMain.DelegateDonneNbZonesDeTexte(frmMDIMain.Instance().DonneNbZonesDeTexte);
			object[] obj = new object[1];
			obj[0] = id;
			return (long)RouleSurFilPrincipal(del, ref obj);
		}

		public string DonnePolice(long idDoc, long idZone)
		{
			Delegate del = new frmMDIMain.DelegateDonnePolice(frmMDIMain.Instance().DonnePolice);
			object[] obj = new object[2];
			obj[0] = idDoc;
			obj[1] = idZone;
			return (string)RouleSurFilPrincipal(del, ref obj);
		}

		public void DonneTitreDocCourantTest()
		{
			frmMDIMain.Instance().DonneTitreDocCourant();
		}

		public string DonneTitreDocCourant()
		{
			Delegate del = new frmMDIMain.DelegateDonneTitreDocCourant(frmMDIMain.Instance().DonneTitreDocCourant);
			return (string)RouleSurFilPrincipal(del);
		}

		public void RemplaceIntervalle(long idDoc, long idZone, long leDebut, long laFin, ref string laChaine)
		{
			Delegate del = new frmMDIMain.DelegateRemplaceIntervalle(frmMDIMain.Instance().RemplaceIntervalle);
			object[] obj = new object[5];
			obj[0] = idDoc;
			obj[1] = idZone;
			obj[2] = (int)leDebut;
			obj[3] = (int)laFin;
			obj[4] = laChaine;
			RouleSurFilPrincipal(del, ref obj);
			laChaine = (string)obj[4];
		}

		public void SelectionneIntervalle(long idDoc, long idZone, long leDebut, long laFin)
		{
			Delegate del = new frmMDIMain.DelegateSelectionneIntervalle(frmMDIMain.Instance().SelectionneIntervalle);
			object[] obj = new object[4];
			obj[0] = idDoc;
			obj[1] = idZone;
			obj[2] = (int)leDebut;
			obj[3] = (int)laFin;
			RouleSurFilPrincipal(del,ref obj);
		}

		private object RouleSurFilPrincipal(Delegate del, ref object[] objs)
		{
			frmMDIMain frm = frmMDIMain.Instance();
			IAsyncResult result = frm.BeginInvoke(del, objs);
			return frm.EndInvoke(result);
		}

		private object RouleSurFilPrincipal(Delegate del)
		{
			frmMDIMain frm = frmMDIMain.Instance();
			IAsyncResult result = frm.BeginInvoke(del);
			return frm.EndInvoke(result);
		}
	}

	[Guid("4EB52B9F-586B-454d-B6B7-8F202B335A4E")]
	[InterfaceType(ComInterfaceType.InterfaceIsIDispatch)]
	[ComVisible(true)]
	public interface IServeurClient
	{
		void ActiveApplication();
		void ActiveDocument(long idDoc);
		long DonneDebutSelection(long idDoc, long idZone);
		long DonneFinSelection(long idDoc, long idZone);
		long DonneIdDocumentCourant();
		long DonneIdZoneDeTexte(long id, long indice);
		long DonneIdZoneDeTexteCourante(long id);
		string DonneIntervalle(long idDoc, long idZone, long leDebut, long laFin);
		long DonneLongueurZoneDeTexte(long idDoc, long idZone);
		long DonneNbZonesDeTexte(long id);
		string DonnePolice(long idDoc, long idZone);
		string DonneTitreDocCourant();
		void RemplaceIntervalle(long idDoc, long idZone, long leDebut, long laFin, ref string laChaine);
		void SelectionneIntervalle(long idDoc, long idZone, long leDebut, long laFin);
	}
}