﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Threading;
using System.Windows.Forms;
using Microsoft.Win32;
using System.Runtime.InteropServices;
using Antidote_APIOle_VCSharp_dotNet;
using System.Globalization;

namespace Antidote_APIOle_VCSharp_dotNet
{
	[ComVisible(false)]
	public partial class frmMDIMain : Form
	{
		int noDocument = 0;
		List<Form> d;
		String maLangue;

		// ----------------------------------------------------------------------------
		// ActiveApplication : Active l'application pour la mettre en avant-plan.
		//
		// ActiveApplication: Activates the application and places it in the foreground.
		// ----------------------------------------------------------------------------
		public delegate void DelegateActiveApplication();
		public void ActiveApplication()
		{
			BringToFront();
			Activate();
		}

		// ----------------------------------------------------------------------------
		// ActiveDocument : Active le document spécifié pour le mettre devant les autres documents.
		//
		// ActiveDocument: Activates the specified documents and places it on top of the others.
		// ----------------------------------------------------------------------------
		public delegate void DelegateActiveDocument(long idDoc);
		public void ActiveDocument(long idDoc)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return;
			t.BringToFront();
			ActivateMdiChild(t);
		}

		// ----------------------------------------------------------------------------
		// DonneDebutSelection : Retourne la position du début de la sélection pour la zone de texte idZoneDeTexte du document idDocument.
		//
		// DonneDebutSelection: Returns the beginning of the selection in the text box 'idZoneDeTexte' in the document idDocument.
		// ----------------------------------------------------------------------------
		public delegate long DelegateDonneDebutSelection(long idDoc, long idZone);
		public long DonneDebutSelection(long idDoc, long idZone)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return -1;
			return ((ChildMDIfrm)t).DonneDebutSelection(idZone);
		}

		// ----------------------------------------------------------------------------
		// DonneFinSelection : Retourne la position de la fin de la sélection pour la zone de texte idZoneDeTexte du document idDocument.
		//
		// DonneFinSelection: Returns the end of the selection in the text box 'idZoneDeTexte' in the document idDocument.
		// ----------------------------------------------------------------------------
		public delegate long DelegateDonneFinSelection(long idDoc, long idZone);
		public long DonneFinSelection(long idDoc, long idZone)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return -1;
			return ((ChildMDIfrm)t).DonneFinSelection(idZone);
		}

		// ----------------------------------------------------------------------------
		// DonneIdDocumentCourant : Retourne l’identificateur du document courant (le document en avant-plan).
		//
		// DonneIdDocumentCourant: Returns the identifier of the current document (the one that is on top).
		// ----------------------------------------------------------------------------
		public delegate long DelegateDonneIdDocumentCourant();
		public long DonneIdDocumentCourant()
		{
			Form t = DonneDocumentCourant();
			long val = -1;
			if (t != null)
				val = long.Parse(t.Tag.ToString());
			return val;
		}

		// ----------------------------------------------------------------------------
		// DonneIdZoneDeTexte : Retourne l’identificateur de la zone de texte correspondant à l’indice indiceZoneDeTexte dans le document idDocument.
		//
		// DonneIdZoneDeTexte: Returns the ID of the text box corresponding to the indiceZoneDeTexte index for the idDocument document.
		// ----------------------------------------------------------------------------
		public delegate long DelegateDonneIdZoneDeTexte(long idDoc, long indice);
		public long DonneIdZoneDeTexte(long idDoc, long indice)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return -1;
			return ((ChildMDIfrm)t).DonneIdZoneDeTexte((int)indice);
		}

		// ----------------------------------------------------------------------------
		// DonneIdZoneDeTexteCourante : Retourne l’identificateur de la zone de texte courante (la zone de texte qui contient le curseur).
		//
		// DonneIdZoneDeTexteCourante: Returns the ID of the current text box (where the text cursor is currently placed).
		// ----------------------------------------------------------------------------
		public delegate long DelegateDonneIdZoneDeTexteCourante(long idDoc);
		public long DonneIdZoneDeTexteCourante(long idDoc)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return -1;
			return ((ChildMDIfrm)t).DonneIdZoneActive();
		}

		// ----------------------------------------------------------------------------
		// DonneIntervalle : Retourne le texte de la zone de texte idZoneDeTexte, de la position leDebut jusqu’à la position laFin, dans le document idDocument.
		//
		// DonneIntervalle: Returns the contents of the text box idZoneDeTexte, from "leDebut" to "laFin", in the idDocument document.
		// ----------------------------------------------------------------------------
		public delegate string DelegateDonneIntervalle(long idDoc, long idZone, int leDebut, int laFin);
		public string DonneIntervalle(long idDoc, long idZone, int leDebut, int laFin)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return "";
			return ((ChildMDIfrm)t).DonneIntervalle(idZone, leDebut, laFin);
		}

		// ----------------------------------------------------------------------------
		// DonneLongueurZoneDeTexte : Retourne la longueur de la zone de texte idZoneDeTexte dans le document idDocument.
		//
		// DonneLongueurZoneDeTexte: Returns the number of characters in the text box indicated by 'idZoneDeTexte' in the idDocument document.
		// ----------------------------------------------------------------------------
		public delegate long DelegateDonneLongueurZoneDeTexte(long idDoc, long idZone);
		public long DonneLongueurZoneDeTexte(long idDoc, long idZone)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return -1;
			return ((ChildMDIfrm)t).DonneLongueurZoneDeTexte(idZone);
		}

		// ----------------------------------------------------------------------------
		// DonneNbZonesDeTexte : Retourne le nombre de zones de texte dans le document spécifié.
		//
		// DonneNbZonesDeTexte: Returns the number of text boxes in the idDocument document.
		// ----------------------------------------------------------------------------
		public delegate long DelegateDonneNbZonesDeTexte(long idDoc);
		public long DonneNbZonesDeTexte(long idDoc)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return -1;
			return ((ChildMDIfrm)t).DonneNbBoitesTexte();
		}

		// ----------------------------------------------------------------------------
		// DonnePolice :  Méthode obsolète présente pour rétrocompatibilité uniquement. Retourner une chaine vide.
		//
		// DonnePolice:  Obsolete method present only for reasons of backward compatibility. Returns an empty string.
		// ----------------------------------------------------------------------------
		public delegate string DelegateDonnePolice(long idDoc, long idZone);
		public string DonnePolice(long idDoc, long idZone)
		{
			return "";
		}

		// ----------------------------------------------------------------------------
		// DonneTitreDocCourant : Retourne le titre du document courant.
		//
		// DonneTitreDocCourant: Returns the name of the current document.
		// ----------------------------------------------------------------------------
		public delegate string DelegateDonneTitreDocCourant();
		public string DonneTitreDocCourant()
		{
			Form t = DonneDocumentCourant();
			if (t == null)
				return "";
			return t.Text;
		}

		// ----------------------------------------------------------------------------
		// RemplaceIntervalle : Remplace le texte à l'endroit spécifié
		//
		// RemplaceIntervalle: Replaces the text in the specified location.
		// ----------------------------------------------------------------------------
		public delegate void DelegateRemplaceIntervalle(long idDoc, long idZone, int leDebut, int laFin, ref string laChaine);
		public void RemplaceIntervalle(long idDoc, long idZone, int leDebut, int laFin, ref string laChaine)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return;
			((ChildMDIfrm)t).RemplaceIntervalle(idZone, leDebut, laFin, ref laChaine);
		}

		// ----------------------------------------------------------------------------
		// SelectionneIntervalle : Sélectionne le texte à l'endroit spécifié
		//
		// SelectionneIntervalle: Selects the text in the specified location.
		// ----------------------------------------------------------------------------
		public delegate void DelegateSelectionneIntervalle(long idDoc, long idZone, int leDebut, int laFin);
		public void SelectionneIntervalle(long idDoc, long idZone, int leDebut, int laFin)
		{
			Form t = null;
			DonneDocument(idDoc, ref t);
			if (t == null)
				return;
			ActiveDocument(idDoc);
			((ChildMDIfrm)t).SelectionneIntervalle(idZone, leDebut, laFin);
		}

		private Form DonneDocumentCourant()
		{
			return this.ActiveMdiChild;
		}

		private void DonneDocument(long id, ref Form bte)
		{
			bte = null;
			if (id == -1)
				return;
			else
			{
				List<Form>.Enumerator it = d.GetEnumerator();
				while (it.MoveNext())
				{
					if (it.Current == null)
						break;
					long val = long.Parse(it.Current.Tag.ToString());
					if (val == id)
					{
						bte = it.Current;
						break;
					}
				}
			}
		}

		private static frmMDIMain singleton = null;

		public static frmMDIMain Instance()
		{
			if (singleton == null)
				singleton = new frmMDIMain();
			return singleton;
		}

		private void CreeMenu(ToolStripSplitButton btn, List<Assoc> liste)
		{
			List<Assoc>.Enumerator it = liste.GetEnumerator();
			while (it.MoveNext())
			{
				ToolStripItem item = new ToolStripMenuItem();
				item.Text = it.Current.texte;
				item.Tag = it.Current.tag;
				item.Click += new System.EventHandler(this.ElementMenuAntidote_Clique);
				btn.DropDownItems.Add(item);
			}
		}

		public void FermetureDocumentEventHandler(object sender, FormClosedEventArgs e)
		{
			d.Remove((Form)sender);
		}

		private frmMDIMain()
		{
			InitializeComponent();
			d = new List<Form>();
			CreeMenu(this.btnDictionnaire, ConstantesOutils.listeDictionnaires);
			CreeMenu(this.btnGuides, ConstantesOutils.listeGuides);
			fromContextToolStripMenuItem.Checked = true;
		}

		private void ShowNewForm(object sender, EventArgs e)
		{
			int childFormNumber = noDocument + 1;
			ChildMDIfrm childForm = new ChildMDIfrm(childFormNumber);
			childForm.FormClosed += new FormClosedEventHandler(this.FermetureDocumentEventHandler);
			childForm.Tag = childFormNumber;
			noDocument = childFormNumber;
			d.Add(childForm);
			childForm.MdiParent = this;
			childForm.Text = "Document " + childFormNumber++;
			childForm.Show();
		}

		protected override void OnClosing(CancelEventArgs e)
		{
			ServeurAntidote.InformeAntidoteQueJeMeFerme();
			base.OnClosing(e);
		}

		private TextBox DonneBoiteDeTexteCourante()
		{
			Form f = this.DonneDocumentCourant();
			if (f != null)
				return ((ChildMDIfrm)f).DonneZoneActive();
			return null;
		}

		private void ExitToolsStripMenuItem_Click(object sender, EventArgs e)
		{
			this.Close();
		}

		private void CutToolStripMenuItem_Click(object sender, EventArgs e)
		{
			TextBox t = DonneBoiteDeTexteCourante();
			if (t != null)
				t.Cut();
		}

		private void CopyToolStripMenuItem_Click(object sender, EventArgs e)
		{
			TextBox t = DonneBoiteDeTexteCourante();
			if (t != null)
				t.Copy();
		}

		private void PasteToolStripMenuItem_Click(object sender, EventArgs e)
		{
			TextBox t = DonneBoiteDeTexteCourante();
			if (t != null)
				t.Paste();
		}

		private void selectAllToolStripMenuItem_Click(object sender, EventArgs e)
		{
			TextBox t = DonneBoiteDeTexteCourante();
			if (t != null)
				t.SelectAll();
		}

		private void CascadeToolStripMenuItem_Click(object sender, EventArgs e)
		{
			LayoutMdi(MdiLayout.Cascade);
		}

		private void TileVerticalToolStripMenuItem_Click(object sender, EventArgs e)
		{
			LayoutMdi(MdiLayout.TileVertical);
		}

		private void TileHorizontalToolStripMenuItem_Click(object sender, EventArgs e)
		{
			LayoutMdi(MdiLayout.TileHorizontal);
		}

		private void ArrangeIconsToolStripMenuItem_Click(object sender, EventArgs e)
		{
			LayoutMdi(MdiLayout.ArrangeIcons);
		}

		private void CloseAllToolStripMenuItem_Click(object sender, EventArgs e)
		{
			foreach (Form childForm in MdiChildren)
			{
				childForm.Close();
			}
		}

		private void BoutonDictionnaires_Click(object sender, EventArgs e)
		{
			ServeurAntidote.AppelleAntidote(ConstantesOutils.kDictionnaireDernierChoisi, maLangue);
		}

		private void ElementMenuAntidote_Clique(object sender, EventArgs e)
		{
			string val = (string)((ToolStripItem)sender).Tag;
			ServeurAntidote.AppelleAntidote(val, maLangue);
		}

		private void BoutonCorrecteur_Click(object sender, EventArgs e)
		{
			ServeurAntidote.AppelleAntidote(ConstantesOutils.kOutilCorrecteur, "");
		}

		private void BtnDictionnaire_ButtonClick(object sender, EventArgs e)
		{
			ServeurAntidote.AppelleAntidote(ConstantesOutils.kDictionnaireDernierChoisi, maLangue);
		}

		private void btnGuides_ButtonClick(object sender, EventArgs e)
		{
			ServeurAntidote.AppelleAntidote(ConstantesOutils.kGuideDernierChoisi, maLangue);
		}

		private void fileMenu_Click(object sender, EventArgs e)
		{

		}

		private void languageToolStripMenuItem_Click(object sender, EventArgs e)
		{

		}

		private void fromContextToolStripMenuItem_Click(object sender, EventArgs e)
		{
			maLangue = ConstantesOutils.kLangueSelonContexte;
			forceEnglishToolStripMenuItem.Checked = false;
			forceFrenchToolStripMenuItem.Checked = false;
		}

		private void forceEnglishToolStripMenuItem_Click(object sender, EventArgs e)
		{
			maLangue = ConstantesOutils.kLangueForcerAnglais;
			fromContextToolStripMenuItem.Checked = false;
			forceFrenchToolStripMenuItem.Checked = false;
		}

		private void forceFrenchToolStripMenuItem_Click(object sender, EventArgs e)
		{
			maLangue = ConstantesOutils.kLangueForcerFrancais;
			fromContextToolStripMenuItem.Checked = false;
			forceEnglishToolStripMenuItem.Checked = false;
		}
	}
}
